pub enum ReviewCommentResolution {
Fixed,
NoChangeNeeded,
}Expand description
Agent-reported disposition for one forge review thread.
Variants
Fixed
The agent addressed the review thread in the worktree.
NoChangeNeeded
The agent determined that no code or documentation change was needed.